import json
import os

import requests
import rq
from osgeo import ogr

from app.mission_jobs.image_slice import slice_zxy
from app.utils.create_geojsonl import calc_minmax_zoom
from config import Config
from connection import Connection
from starearth.utils.general_utils import print_log


def image_slice_job(data_path, output_path, tile_size, tile_grid, tile_format, epsg, auto_zoom, min_zoom, max_zoom, dms_id, dms_data):
    config = Config()
    # connection = Connection(config)

    # # 添加任务
    # q = rq.Queue(name='default', connection=connection.redis_conn)
    # for file_name in os.listdir(data_path):
    #     input_file = os.path.join(data_path, file_name)
    #     if os.path.splitext(file_name)[-1] == ".tif":
    #         q.enqueue(slice_zxy,
    #                   kwargs={"input_file": input_file,
    #                           "output_path": output_path,
    #                           "tile_size": tile_size,
    #                           "tile_grid": tile_grid,
    #                           "tile_format": tile_format,
    #                           "auto_zoom": auto_zoom,
    #                           "min_zoom": min_zoom,
    #                           "max_zoom": max_zoom},
    #                   job_timeout=int(config.common.JOB_TIMEOUT)
    #                   )

    for file_name in os.listdir(data_path):
        if os.path.splitext(file_name)[-1] == ".tif":
            input_file = os.path.join(data_path, file_name)

            if auto_zoom:
                # min_zoom, max_zoom = calc_minmax_zoom2(input_file, epsg, tile_size)
                min_zoom, max_zoom = calc_minmax_zoom(input_file, epsg, tile_size)

            slice_zxy(
                input_file=input_file,
                output_path=output_path,
                tile_size=tile_size,
                tile_grid=tile_grid,
                tile_format=tile_format,
                epsg=epsg,
                min_zoom=min_zoom,
                max_zoom=max_zoom,
            )

    # 获取token
    login_data = {
        'userName': config.oauth.userName,
        'password': config.oauth.password,
        'clientId': config.oauth.clientId,
        'serviceId': config.oauth.serviceId
    }

    login_rep = requests.post(config.oauth.URL + '/api/user/login', data=login_data).json()

    headers = {'token': login_rep.get('message')}

    geojsonl_file_list = []

    for file_name in os.listdir(data_path):
        if os.path.splitext(file_name)[-1] == ".geojsonl":
            geojsonl_file = os.path.join(data_path, file_name)
            geojsonl_file_list.append(geojsonl_file)

    new_geometry = None
    for geojsonl_file in geojsonl_file_list:
        with open(geojsonl_file, 'r') as f:
            geometry = json.loads(f.read())['geometry']
        if new_geometry is None:
            src_geometry = ogr.CreateGeometryFromJson(json.dumps(geometry))
        else:
            src_geometry = new_geometry
        dst_geometry = ogr.CreateGeometryFromJson(json.dumps(geometry))
        new_geometry = src_geometry.Union(dst_geometry)

    dms_data['content'] = json.loads(dms_data['content'])
    dms_data['content']['bbox'] = new_geometry.ExportToJson()
    dms_data['content']['c_zoom_min'] = min_zoom
    dms_data['content']['c_zoom_max'] = max_zoom
    dms_data['content']['id'] = dms_id
    dms_data['content'] = json.dumps(dms_data['content'], ensure_ascii=False)

    # 修改dms
    updateContent = requests.post(config.dms.URL + '/content/updateContent', headers=headers, data=dms_data)
    print_log(str(updateContent.json()))
    # 提交dms
    data = {
        'id': dms_id,
        'columnId': config.dms.columnId,
        'state': 1
    }

    updateAudit = requests.post(config.dms.URL + '/content/updateAudit', headers=headers, data=data)
    print_log(str(updateAudit.json()))
